.. image:: https://img.shields.io/pypi/v/dvg-qdeviceio
    :target: https://pypi.org/project/dvg-qdeviceio
.. image:: https://img.shields.io/pypi/pyversions/dvg-qdeviceio
    :target: https://pypi.org/project/dvg-qdeviceio
.. image:: https://travis-ci.org/Dennis-van-Gils/python-dvg-qdeviceio.svg?branch=master
    :target: https://travis-ci.org/Dennis-van-Gils/python-dvg-qdeviceio
.. image:: https://coveralls.io/repos/github/Dennis-van-Gils/python-dvg-qdeviceio/badge.svg?branch=master
    :target: https://coveralls.io/github/Dennis-van-Gils/python-dvg-qdeviceio?branch=master
.. image:: https://requires.io/github/Dennis-van-Gils/python-dvg-qdeviceio/requirements.svg?branch=master
     :target: https://requires.io/github/Dennis-van-Gils/python-dvg-qdeviceio/requirements/?branch=master
     :alt: Requirements Status
.. image:: https://readthedocs.org/projects/python-dvg-qdeviceio/badge/?version=latest
    :target: https://python-dvg-qdeviceio.readthedocs.io/en/latest/?badge=latest
.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
.. image:: https://img.shields.io/badge/License-MIT-purple.svg
    :target: https://github.com/Dennis-van-Gils/python-dvg-qdeviceio/blob/master/LICENSE.txt

DvG_QDeviceIO
=============
Hassle-free PyQt5 interface for multithreaded data acquisition and communication with an I/O device.

It will manage the creation and handling of the threads, workers and signals for you, reducing it to just a few simple method calls of a QDeviceIO class instance to get set up and going.

Documentation is available at https://python-dvg-qdeviceio.readthedocs.io.
